API docs for “spamfighter.core.test.test_log.LogEntryTestCase”

# Class s.c.t.t.LogEntryTestCase(unittest.TestCase):

Part of spamfighter.core.test.test_log View Source View In Hierarchy

Тест на `spamfighter.core.log.LogEntry`.

Method | setUp | Undocumented
Method | testInterface | Undocumented
Method | testSerialize | Undocumented
Method | testUnserialize | Undocumented
Method | testConstructor | Undocumented

def setUp(self): (source)
Undocumented
def testInterface(self): (source)
Undocumented
def testSerialize(self): (source)
Undocumented
def testUnserialize(self): (source)
Undocumented
def testConstructor(self): (source)
Undocumented